@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2019 Canonical
+ * Copyright (C) 2011-2020 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -2227,7 +2227,7 @@ int main(int argc, char **argv)
 	if (optind < argc) {
 		duration_secs = atof(argv[optind++]);
 		if (duration_secs < 0.333) {
-			(void)fprintf(stderr, "Duration must 0.333 or more\n");
+			(void)fprintf(stderr, "Delay duration must 0.333 or more\n");
 			exit(EXIT_FAILURE);
 		}
 	}
